/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.ow2.weblab.core.annotator;

import java.net.URI;

import org.ow2.weblab.rdf.CommonNamespaces;
import org.w3c.dom.Node;

/**
 * This class defines properties used to build the container
 * in which statements are read and written.
 * 
 */
public class Element {

	private String localName;
	private String uri;
	private String prefix;

	public Element(String prefix, String uri, String localName) {
		this.localName = localName;
		this.uri = uri;
		this.prefix = prefix;
	}

	public String getLocalName() {
		return this.localName;
	}

	public void setLocalName(String localName) {
		this.localName = localName;
	}

	public String getUri() {
		return this.uri;
	}

	public void setUri(String uri) {
		this.uri = uri;
	}

	public String getPrefix() {
		return this.prefix;
	}

	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	public int hashCode() {
		return (this.uri+this.localName).hashCode();
	}
	
	public boolean equals(Object object) {
		if (!(object instanceof Node)){
			return false;
		}
		
		Node n = (Node)object;
		
		String name = n.getLocalName();
		String nuri = n.getNamespaceURI();

		if (name != null && nuri != null && this.localName != null && this.uri != null && name.equalsIgnoreCase(this.localName) && nuri.equalsIgnoreCase(this.uri)) {
			return true;
		}

		return false;
	}

	public static final Element getDefaultElement() {
		return new Element(CommonNamespaces.RDF_PREFIX, CommonNamespaces.RDF_URI, "Description");
	}

	public URI toURI() {
		return URI.create(this.uri + this.localName);
	}
}