/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */
package org.ow2.weblab.core.model;

import java.net.URI;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.rdf.Value;

 /**
  * WebLab Exchange model v1.2.1 - May 2011
  *  This version includes annotable object of the model i.e. Resources and their relationships.
  *  It also provides some properties to be used in annotations.
  * 
  *  WEBLAB: Service oriented integration platform for media mining and intelligence applications Copyright (C) 2004 - 2011 Cassidian, an EADS company
  */
public class WModelAnnotator extends BaseAnnotator {

	protected static final String APREFIX = "wmodel";
	protected static final URI AURI = URI.create("http://weblab.ow2.org/core/1.2/ontology/model#");

	public WModelAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public WModelAnnotator(Resource resource){
		super(resource);
	}

	protected static final String IS_COMPOSED_BY_QUERY = "isComposedByQuery";
	protected static final String IN_RESULT_SET = "inResultSet";
	protected static final String HAS_CONTENT = "hasContent";
	protected static final String HAS_COORDINATE = "hasCoordinate";
	protected static final String HAS_LOW_LEVEL_DESCRIPTOR = "hasLowLevelDescriptor";
	protected static final String IS_COMPOSED_BY_MEDIA_UNIT = "isComposedByMediaUnit";
	protected static final String IN_DOCUMENT = "inDocument";
	protected static final String HAS_ORDINATE = "hasOrdinate";
	protected static final String HAS_REQUEST = "hasRequest";
	protected static final String HAS_WEIGHT = "hasWeight";
	protected static final String IN_COMPOSED_RESOURCE = "inComposedResource";
	protected static final String HAS_SEGMENT = "hasSegment";
	protected static final String HAS_ANNOTATION = "hasAnnotation";
	protected static final String HAS_URI = "hasUri";
	protected static final String IS_COMPOSED_BY_RESOURCE_RESULT_SET = "isComposedByResourceResultSet";
	protected static final String HAS_TIME_STAMP = "hasTimeStamp";
	protected static final String HAS_DATA = "hasData";
	protected static final String IS_COMPOSED_BY_SEGMENT = "isComposedBySegment";
	protected static final String START_AT = "startAt";
	protected static final String HAS_OPERATOR = "hasOperator";
	protected static final String END_AT = "endAt";
	protected static final String IS_COMPOSED_BY_RESOURCE = "isComposedByResource";
	protected static final String HAS_POK = "hasPok";
	protected static final String IN_COMPOSED_QUERY = "inComposedQuery";
	protected static final String HAS_ABSCISSA = "hasAbscissa";
	protected static final String HAS_TEXT_CONTENT = "hasTextContent";

	/**
	 * Read the Links a ComposedQuery to one of its Query. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readComposedByQuery(){
		return applyOperator(Operator.READ, null,AURI, IS_COMPOSED_BY_QUERY, URI.class, null);
	}


	/**
	 * Write the Links a ComposedQuery to one of its Query.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeComposedByQuery(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COMPOSED_BY_QUERY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a resource to its parent ResultSet. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInResultSet(){
		return applyOperator(Operator.READ, null,AURI, IN_RESULT_SET, URI.class, null);
	}


	/**
	 * Write the Links a resource to its parent ResultSet.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInResultSet(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IN_RESULT_SET, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The optional content as a bytes array. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readContent(){
		return applyOperator(Operator.READ, null,AURI, HAS_CONTENT, URI.class, null);
	}


	/**
	 * Write the The optional content as a bytes array.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeContent(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CONTENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a SpatialSegment to one of its Coordinate. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCoordinate(){
		return applyOperator(Operator.READ, null,AURI, HAS_COORDINATE, URI.class, null);
	}


	/**
	 * Write the Links a SpatialSegment to one of its Coordinate.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeCoordinate(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_COORDINATE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a Resource to one of its LowLevelDescriptor. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLowLevelDescriptor(){
		return applyOperator(Operator.READ, null,AURI, HAS_LOW_LEVEL_DESCRIPTOR, URI.class, null);
	}


	/**
	 * Write the Links a Resource to one of its LowLevelDescriptor.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLowLevelDescriptor(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_LOW_LEVEL_DESCRIPTOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a Document to one of its sub-MediaUnit. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readComposedByMediaUnit(){
		return applyOperator(Operator.READ, null,AURI, IS_COMPOSED_BY_MEDIA_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a Document to one of its sub-MediaUnit.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeComposedByMediaUnit(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COMPOSED_BY_MEDIA_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a MediaUnit to its parent Document. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInDocument(){
		return applyOperator(Operator.READ, null,AURI, IN_DOCUMENT, URI.class, null);
	}


	/**
	 * Write the Links a MediaUnit to its parent Document.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInDocument(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IN_DOCUMENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Ordinate value in pixels, with 0 at the bottom border. Other measure references are possible. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readOrdinate(){
		return applyOperator(Operator.READ, null,AURI, HAS_ORDINATE, Integer.class, null);
	}


	/**
	 * Write the Ordinate value in pixels, with 0 at the bottom border. Other measure references are possible.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeOrdinate(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ORDINATE, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The string query in a free text syntax. 
	 * 
	 * @return a String
	 */
	public Value<String> readRequest(){
		return applyOperator(Operator.READ, null,AURI, HAS_REQUEST, String.class, null);
	}


	/**
	 * Write the The string query in a free text syntax.
	 * @param value a String
	 */
	public PieceOfKnowledge writeRequest(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_REQUEST, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A weight used for Query combination. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readWeight(){
		return applyOperator(Operator.READ, null,AURI, HAS_WEIGHT, URI.class, null);
	}


	/**
	 * Write the A weight used for Query combination.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeWeight(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_WEIGHT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a resource to its parent ComposedResource or SimilarityQuery 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInComposedResource(){
		return applyOperator(Operator.READ, null,AURI, IN_COMPOSED_RESOURCE, URI.class, null);
	}


	/**
	 * Write the Links a resource to its parent ComposedResource or SimilarityQuery
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInComposedResource(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IN_COMPOSED_RESOURCE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a MediaUnit to one of its Segment. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSegment(){
		return applyOperator(Operator.READ, null,AURI, HAS_SEGMENT, URI.class, null);
	}


	/**
	 * Write the Links a MediaUnit to one of its Segment.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeSegment(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_SEGMENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a Resource to one of its Annotation. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAnnotation(){
		return applyOperator(Operator.READ, null,AURI, HAS_ANNOTATION, URI.class, null);
	}


	/**
	 * Write the Links a Resource to one of its Annotation.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAnnotation(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ANNOTATION, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The unique identifier of a Resource or a Segment. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readUri(){
		return applyOperator(Operator.READ, null,AURI, HAS_URI, URI.class, null);
	}


	/**
	 * Write the The unique identifier of a Resource or a Segment.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeUri(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_URI, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a ResultSet to one of its Resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readComposedByResourceResultSet(){
		return applyOperator(Operator.READ, null,AURI, IS_COMPOSED_BY_RESOURCE_RESULT_SET, URI.class, null);
	}


	/**
	 * Write the Links a ResultSet to one of its Resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeComposedByResourceResultSet(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COMPOSED_BY_RESOURCE_RESULT_SET, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The timestamp of a SpatioTemporalSegment 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readTimeStamp(){
		return applyOperator(Operator.READ, null,AURI, HAS_TIME_STAMP, Integer.class, null);
	}


	/**
	 * Write the The timestamp of a SpatioTemporalSegment
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeTimeStamp(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_TIME_STAMP, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Should be an ARFF content for a LowLevelDescriptor and a RDF/XML content for a PoK. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readData(){
		return applyOperator(Operator.READ, null,AURI, HAS_DATA, URI.class, null);
	}


	/**
	 * Write the Should be an ARFF content for a LowLevelDescriptor and a RDF/XML content for a PoK.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeData(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_DATA, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a TrackSegment to one of its Segment 
	 * 
	 * @return an URI
	 */
	public Value<URI> readComposedBySegment(){
		return applyOperator(Operator.READ, null,AURI, IS_COMPOSED_BY_SEGMENT, URI.class, null);
	}


	/**
	 * Write the Links a TrackSegment to one of its Segment
	 * @param value an URI
	 */
	public PieceOfKnowledge writeComposedBySegment(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COMPOSED_BY_SEGMENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The start value of a LinearSegment (char in UTF-8) or a TemporalSegment (milliseconds). 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readStartAt(){
		return applyOperator(Operator.READ, null,AURI, START_AT, Integer.class, null);
	}


	/**
	 * Write the The start value of a LinearSegment (char in UTF-8) or a TemporalSegment (milliseconds).
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeStartAt(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, START_AT, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the This is a simple restriction of String to reduce the values to the three boolean operators AND/OR/NOT.
	 *  Note that in a n-ary context, the unary operator NOT is considered as a AND NOT. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readOperator(){
		return applyOperator(Operator.READ, null,AURI, HAS_OPERATOR, URI.class, null);
	}


	/**
	 * Write the This is a simple restriction of String to reduce the values to the three boolean operators AND/OR/NOT.
	 *  Note that in a n-ary context, the unary operator NOT is considered as a AND NOT.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeOperator(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_OPERATOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The end value of a LinearSegment (char in UTF-8) or a TemporalSegment (milliseconds). 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readEndAt(){
		return applyOperator(Operator.READ, null,AURI, END_AT, Integer.class, null);
	}


	/**
	 * Write the The end value of a LinearSegment (char in UTF-8) or a TemporalSegment (milliseconds).
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeEndAt(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, END_AT, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a ComposedResource or a SimilarityQuery to one of its Resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readComposedByResource(){
		return applyOperator(Operator.READ, null,AURI, IS_COMPOSED_BY_RESOURCE, URI.class, null);
	}


	/**
	 * Write the Links a ComposedResource or a SimilarityQuery to one of its Resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeComposedByResource(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COMPOSED_BY_RESOURCE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a ResultSet to its PieceOfKnowledge. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readPok(){
		return applyOperator(Operator.READ, null,AURI, HAS_POK, URI.class, null);
	}


	/**
	 * Write the Links a ResultSet to its PieceOfKnowledge.
	 * @param value an URI
	 */
	public PieceOfKnowledge writePok(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_POK, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a Query to its parent ComposedQuery. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInComposedQuery(){
		return applyOperator(Operator.READ, null,AURI, IN_COMPOSED_QUERY, URI.class, null);
	}


	/**
	 * Write the Links a Query to its parent ComposedQuery.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInComposedQuery(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IN_COMPOSED_QUERY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Abscissa value in pixels, with 0 at the left border. Other measure references are possible. 
	 * 
	 * @return an Integer
	 */
	public Value<Integer> readAbscissa(){
		return applyOperator(Operator.READ, null,AURI, HAS_ABSCISSA, Integer.class, null);
	}


	/**
	 * Write the Abscissa value in pixels, with 0 at the left border. Other measure references are possible.
	 * @param value an Integer
	 */
	public PieceOfKnowledge writeAbscissa(Integer value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ABSCISSA, Integer.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The String content of the text. Might be empty, in that case an annotation referring to the whole large
	 *  content should be present. 
	 * 
	 * @return a String
	 */
	public Value<String> readTextContent(){
		return applyOperator(Operator.READ, null,AURI, HAS_TEXT_CONTENT, String.class, null);
	}


	/**
	 * Write the The String content of the text. Might be empty, in that case an annotation referring to the whole large
	 *  content should be present.
	 * @param value a String
	 */
	public PieceOfKnowledge writeTextContent(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_TEXT_CONTENT, String.class, value).getIsAnnotatedOn();
	}



}

