/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.ow2.weblab.rdf;

import java.net.URI;
import java.net.URISyntaxException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import org.apache.commons.logging.LogFactory;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.ow2.weblab.core.annotator.BaseAnnotator;

public class XMLParser {

	private static SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ssZ", Locale.ENGLISH);

	public static URI buildURI(String uri) {
		try {
			return new URI(uri);
		} catch (URISyntaxException e) {
			LogFactory.getLog(BaseAnnotator.class).error(
					"Illegal RDF and RDFS URI modification. This is really strange and could result from a system compromission : " + uri, e);
		}
		return null;
	}

	/**
	 * Parse the value of a property info an instance of T.
	 * 
	 * @param <T>
	 * @param value
	 * @param clazz
	 */
	public static <T> T xmlParse(String value, Class<T> clazz) {
		if (value == null) {
			return null;
		}
		if (clazz.isInstance(new Date())) {
			// Support ISO xsd:date
			
			try{
				DateTimeFormatter parser = ISODateTimeFormat.dateTimeParser();
				return (T) parser.parseDateTime(value).toDate();
				
			}catch(IllegalArgumentException iae){
				LogFactory.getLog(XMLParser.class).error("Can not parse " + value + " into a Date Java Object", iae);
			}catch(ClassCastException cce){
				LogFactory.getLog(XMLParser.class).error("Can not parse " + value + " into a Date Java Object", cce);
			} catch (UnsupportedOperationException e) {
				LogFactory.getLog(XMLParser.class).error("Can not parse " + value + " into a Date Java Object", e);
			}
 
		} else if (clazz.isInstance(buildURI("weblab://dummyURI"))) {
			try {
				return (T) new URI(value);
			} catch (URISyntaxException e) {
				LogFactory.getLog(XMLParser.class).error("Can not parse " + value + " into a legal URI", e);
			}
		} else if (clazz.isInstance(Double.valueOf(0)) || clazz == double.class) {
			return (T) new Double(Double.parseDouble(value));
		} else if (clazz.isInstance(Long.valueOf(0)) || clazz == long.class) {
			return (T) Long.valueOf(value);
		} else if (clazz.isInstance(Integer.valueOf(0)) || clazz == int.class) {
			return (T) Integer.valueOf(value);
		} else if (clazz.isInstance(Boolean.TRUE) || clazz == boolean.class) {
			return (T) Boolean.valueOf(value);
		}
		return (T) value;
	}

	/**
	 * Transform an object into a Literal
	 * 
	 * @param value
	 */
	public static Object xmlTransform(Object value) {
		if (value instanceof Date) {
			value = sdf.format(value);
		}
		return value;
	}

}
