/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

package org.purl.dc.elements;

import java.net.URI;
import java.util.Date;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;

public class DublinCoreAnnotator extends BaseAnnotator {

	protected static final String APREFIX = "dc";
	protected static final URI AURI = URI.create("http://purl.org/dc/elements/1.1/");

	public DublinCoreAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge) {
		super(subject, pieceOfKnowledge);
	}

	public DublinCoreAnnotator(Resource resource) {
		super(resource);
	}

	/**
	 * Read the A name given to the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readTitle() {
		return applyOperator(Operator.READ, null, AURI, TITLE, String.class, null);
	}


	/**
	 * Write the A name given to the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeTitle(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, TITLE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity primarily responsible for making the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readCreator() {
		return applyOperator(Operator.READ, null, AURI, CREATOR, String.class, null);
	}


	/**
	 * Write the An entity primarily responsible for making the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeCreator(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, CREATOR, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The topic of the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readSubject() {
		return applyOperator(Operator.READ, null, AURI, SUBJECT, String.class, null);
	}


	/**
	 * Write the The topic of the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeSubject(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, SUBJECT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An account of the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readDescription() {
		return applyOperator(Operator.READ, null, AURI, DESCRIPTION, String.class, null);
	}


	/**
	 * Write the An account of the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeDescription(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, DESCRIPTION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity responsible for making the resource available.
	 * 
	 * @return a String
	 */
	public Value<String> readPublisher() {
		return applyOperator(Operator.READ, null, AURI, PUBLISHER, String.class, null);
	}


	/**
	 * Write the An entity responsible for making the resource available.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writePublisher(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, PUBLISHER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity responsible for making contributions to the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readContributor() {
		return applyOperator(Operator.READ, null, AURI, CONTRIBUTOR, String.class, null);
	}


	/**
	 * Write the An entity responsible for making contributions to the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeContributor(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, CONTRIBUTOR, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A point or period of time associated with an event in the lifecycle of the resource.
	 * 
	 * @return a String
	 */
	public Value<Date> readDate() {
		return applyOperator(Operator.READ, null, AURI, DATE, Date.class, null);
	}


	/**
	 * Write the A point or period of time associated with an event in the lifecycle of the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeDate(Date value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, DATE, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The file format, physical medium, or dimensions of the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readFormat() {
		return applyOperator(Operator.READ, null, AURI, FORMAT, String.class, null);
	}


	/**
	 * Write the The file format, physical medium, or dimensions of the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeFormat(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, FORMAT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An unambiguous reference to the resource within a given context.
	 * 
	 * @return a String
	 */
	public Value<String> readIdentifier() {
		return applyOperator(Operator.READ, null, AURI, IDENTIFIER, String.class, null);
	}


	/**
	 * Write the An unambiguous reference to the resource within a given context.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeIdentifier(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, IDENTIFIER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource from which the described resource is derived.
	 * 
	 * @return a String
	 */
	public Value<String> readSource() {
		return applyOperator(Operator.READ, null, AURI, SOURCE, String.class, null);
	}


	/**
	 * Write the A related resource from which the described resource is derived.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeSource(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, SOURCE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A language of the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readLanguage() {
		return applyOperator(Operator.READ, null, AURI, LANGUAGE, String.class, null);
	}


	/**
	 * Write the A language of the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeLanguage(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, LANGUAGE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource.
	 * 
	 * @return a String
	 */
	public Value<String> readRelation() {
		return applyOperator(Operator.READ, null, AURI, RELATION, String.class, null);
	}


	/**
	 * Write the A related resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeRelation(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, RELATION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is
	 * relevant.
	 * 
	 * @return a String
	 */
	public Value<String> readCoverage() {
		return applyOperator(Operator.READ, null, AURI, COVERAGE, String.class, null);
	}


	/**
	 * Write the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is
	 * relevant.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeCoverage(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, COVERAGE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Information about rights held in and over the resource.
	 * 
	 * @return a String
	 */
	public Value<String> readRights() {
		return applyOperator(Operator.READ, null, AURI, RIGHTS, String.class, null);
	}


	/**
	 * Write the Information about rights held in and over the resource.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeRights(String value) {
		return applyOperator(Operator.WRITE, APREFIX, AURI, RIGHTS, String.class, value).getIsAnnotatedOn();
	}


	protected static final String TITLE = "title";
	protected static final String CREATOR = "creator";
	protected static final String SUBJECT = "subject";
	protected static final String DESCRIPTION = "description";
	protected static final String PUBLISHER = "publisher";
	protected static final String CONTRIBUTOR = "contributor";
	protected static final String DATE = "date";
	protected static final String TYPE = "type";
	protected static final String FORMAT = "format";
	protected static final String IDENTIFIER = "identifier";
	protected static final String SOURCE = "source";
	protected static final String LANGUAGE = "language";
	protected static final String RELATION = "relation";
	protected static final String COVERAGE = "coverage";
	protected static final String RIGHTS = "rights";

}
