/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2011 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */
package org.purl.dc.terms;

import java.net.URI;
import java.util.Date;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;

 /**
  * 
  */
public class DCTermsAnnotator extends BaseAnnotator {

	protected static final String APREFIX = "dcterms";
	protected static final URI AURI = URI.create("http://purl.org/dc/terms/");

	public DCTermsAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public DCTermsAnnotator(Resource resource){
		super(resource);
	}

	protected static final String IS_REQUIRED_BY = "isRequiredBy";
	protected static final String IDENTIFIER = "identifier";
	protected static final String IS_FORMAT_OF = "isFormatOf";
	protected static final String VALID = "valid";
	protected static final String INSTRUCTIONAL_METHOD = "instructionalMethod";
	protected static final String MEDIUM = "medium";
	protected static final String MEDIATOR = "mediator";
	protected static final String FORMAT = "format";
	protected static final String RELATION = "relation";
	protected static final String SOURCE = "source";
	protected static final String IS_REFERENCED_BY = "isReferencedBy";
	protected static final String RIGHTS = "rights";
	protected static final String ABSTRACT = "abstract";
	protected static final String AUDIENCE = "audience";
	protected static final String BIBLIOGRAPHIC_CITATION = "bibliographicCitation";
	protected static final String LANGUAGE = "language";
	protected static final String LICENSE = "license";
	protected static final String CONFORMS_TO = "conformsTo";
	protected static final String ACCRUAL_POLICY = "accrualPolicy";
	protected static final String DATE_SUBMITTED = "dateSubmitted";
	protected static final String IS_VERSION_OF = "isVersionOf";
	protected static final String RIGHTS_HOLDER = "rightsHolder";
	protected static final String CREATED = "created";
	protected static final String ACCRUAL_METHOD = "accrualMethod";
	protected static final String CREATOR = "creator";
	protected static final String TEMPORAL = "temporal";
	protected static final String ACCESS_RIGHTS = "accessRights";
	protected static final String ISSUED = "issued";
	protected static final String DESCRIPTION = "description";
	protected static final String IS_REPLACED_BY = "isReplacedBy";
	protected static final String AVAILABLE = "available";
	protected static final String REPLACES = "replaces";
	protected static final String DATE = "date";
	protected static final String TABLE_OF_CONTENTS = "tableOfContents";
	protected static final String REQUIRES = "requires";
	protected static final String ACCRUAL_PERIODICITY = "accrualPeriodicity";
	protected static final String HAS_FORMAT = "hasFormat";
	protected static final String TITLE = "title";
	protected static final String DATE_ACCEPTED = "dateAccepted";
	protected static final String HAS_VERSION = "hasVersion";
	protected static final String MODIFIED = "modified";
	protected static final String PUBLISHER = "publisher";
	protected static final String SUBJECT = "subject";
	protected static final String CONTRIBUTOR = "contributor";
	protected static final String TYPE = "type";
	protected static final String EDUCATION_LEVEL = "educationLevel";
	protected static final String DATE_COPYRIGHTED = "dateCopyrighted";
	protected static final String REFERENCES = "references";
	protected static final String PROVENANCE = "provenance";
	protected static final String EXTENT = "extent";
	protected static final String ALTERNATIVE = "alternative";
	protected static final String IS_PART_OF = "isPartOf";
	protected static final String HAS_PART = "hasPart";
	protected static final String COVERAGE = "coverage";
	protected static final String SPATIAL = "spatial";

	/**
	 * Read the A related resource that requires the described resource to support its function, delivery, or coherence. 
	 * 
	 * @return a String
	 */
	public Value<String> readRequiredBy(){
		return applyOperator(Operator.READ, null,AURI, IS_REQUIRED_BY, String.class, null);
	}


	/**
	 * Write the A related resource that requires the described resource to support its function, delivery, or coherence.
	 * @param value a String
	 */
	public PieceOfKnowledge writeRequiredBy(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_REQUIRED_BY, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An unambiguous reference to the resource within a given context. 
	 * 
	 * @return a String
	 */
	public Value<String> readIdentifier(){
		return applyOperator(Operator.READ, null,AURI, IDENTIFIER, String.class, null);
	}


	/**
	 * Write the An unambiguous reference to the resource within a given context.
	 * @param value a String
	 */
	public PieceOfKnowledge writeIdentifier(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IDENTIFIER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is substantially the same as the described resource, but in another format. 
	 * 
	 * @return a String
	 */
	public Value<String> readFormatOf(){
		return applyOperator(Operator.READ, null,AURI, IS_FORMAT_OF, String.class, null);
	}


	/**
	 * Write the A related resource that is substantially the same as the described resource, but in another format.
	 * @param value a String
	 */
	public PieceOfKnowledge writeFormatOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_FORMAT_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date (often a range) of validity of a resource. 
	 * 
	 * @return a String
	 */
	public Value<Date> readValid(){
		return applyOperator(Operator.READ, null,AURI, VALID, Date.class, null);
	}


	/**
	 * Write the Date (often a range) of validity of a resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeValid(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, VALID, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A process, used to engender knowledge, attitudes and skills, that the described resource is designed to support. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInstructionalMethod(){
		return applyOperator(Operator.READ, null,AURI, INSTRUCTIONAL_METHOD, URI.class, null);
	}


	/**
	 * Write the A process, used to engender knowledge, attitudes and skills, that the described resource is designed to support.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeInstructionalMethod(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, INSTRUCTIONAL_METHOD, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The material or physical carrier of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readMedium(){
		return applyOperator(Operator.READ, null,AURI, MEDIUM, URI.class, null);
	}


	/**
	 * Write the The material or physical carrier of the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeMedium(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, MEDIUM, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity that mediates access to the resource and for whom the resource is intended or useful. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readMediator(){
		return applyOperator(Operator.READ, null,AURI, MEDIATOR, URI.class, null);
	}


	/**
	 * Write the An entity that mediates access to the resource and for whom the resource is intended or useful.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeMediator(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, MEDIATOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Write the The file format, physical medium, or dimensions of the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFormat(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FORMAT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readRelation(){
		return applyOperator(Operator.READ, null,AURI, RELATION, String.class, null);
	}


	/**
	 * Write the A related resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeRelation(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RELATION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource from which the described resource is derived. 
	 * 
	 * @return a String
	 */
	public Value<String> readSource(){
		return applyOperator(Operator.READ, null,AURI, SOURCE, String.class, null);
	}


	/**
	 * Write the A related resource from which the described resource is derived.
	 * @param value a String
	 */
	public PieceOfKnowledge writeSource(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, SOURCE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that references, cites, or otherwise points to the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReferencedBy(){
		return applyOperator(Operator.READ, null,AURI, IS_REFERENCED_BY, String.class, null);
	}


	/**
	 * Write the A related resource that references, cites, or otherwise points to the described resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeReferencedBy(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_REFERENCED_BY, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Information about rights held in and over the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRights(){
		return applyOperator(Operator.READ, null,AURI, RIGHTS, URI.class, null);
	}


	/**
	 * Write the Information about rights held in and over the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRights(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RIGHTS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A summary of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readAbstract(){
		return applyOperator(Operator.READ, null,AURI, ABSTRACT, String.class, null);
	}


	/**
	 * Write the A summary of the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeAbstract(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ABSTRACT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A class of entity for whom the resource is intended or useful. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAudience(){
		return applyOperator(Operator.READ, null,AURI, AUDIENCE, URI.class, null);
	}


	/**
	 * Write the A class of entity for whom the resource is intended or useful.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAudience(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, AUDIENCE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A bibliographic reference for the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readBibliographicCitation(){
		return applyOperator(Operator.READ, null,AURI, BIBLIOGRAPHIC_CITATION, String.class, null);
	}


	/**
	 * Write the A bibliographic reference for the resource.
	 * @param value a PieceOfKnowledge
	 */
	public PieceOfKnowledge writeBibliographicCitation(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, BIBLIOGRAPHIC_CITATION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A language of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLanguage(){
		return applyOperator(Operator.READ, null,AURI, LANGUAGE, URI.class, null);
	}


	/**
	 * Write the A language of the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLanguage(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LANGUAGE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A legal document giving official permission to do something with the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLicense(){
		return applyOperator(Operator.READ, null,AURI, LICENSE, URI.class, null);
	}


	/**
	 * Write the A legal document giving official permission to do something with the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLicense(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LICENSE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An established standard to which the described resource conforms. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readConformsTo(){
		return applyOperator(Operator.READ, null,AURI, CONFORMS_TO, URI.class, null);
	}


	/**
	 * Write the An established standard to which the described resource conforms.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeConformsTo(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CONFORMS_TO, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The policy governing the addition of items to a collection. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccrualPolicy(){
		return applyOperator(Operator.READ, null,AURI, ACCRUAL_POLICY, URI.class, null);
	}


	/**
	 * Write the The policy governing the addition of items to a collection.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAccrualPolicy(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ACCRUAL_POLICY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date of submission of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDateSubmitted(){
		return applyOperator(Operator.READ, null,AURI, DATE_SUBMITTED, Date.class, null);
	}


	/**
	 * Write the Date of submission of the resource.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeDateSubmitted(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DATE_SUBMITTED, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource of which the described resource is a version, edition, or adaptation. 
	 * 
	 * @return a String
	 */
	public Value<String> readVersionOf(){
		return applyOperator(Operator.READ, null,AURI, IS_VERSION_OF, String.class, null);
	}


	/**
	 * Write the A related resource of which the described resource is a version, edition, or adaptation.
	 * @param value a String
	 */
	public PieceOfKnowledge writeVersionOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_VERSION_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A person or organization owning or managing rights over the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRightsHolder(){
		return applyOperator(Operator.READ, null,AURI, RIGHTS_HOLDER, URI.class, null);
	}


	/**
	 * Write the A person or organization owning or managing rights over the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRightsHolder(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RIGHTS_HOLDER, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date of creation of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readCreated(){
		return applyOperator(Operator.READ, null,AURI, CREATED, Date.class, null);
	}


	/**
	 * Write the Date of creation of the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCreated(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CREATED, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The method by which items are added to a collection. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccrualMethod(){
		return applyOperator(Operator.READ, null,AURI, ACCRUAL_METHOD, URI.class, null);
	}


	/**
	 * Write the The method by which items are added to a collection.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAccrualMethod(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ACCRUAL_METHOD, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity primarily responsible for making the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCreator(){
		return applyOperator(Operator.READ, null,AURI, CREATOR, URI.class, null);
	}


	/**
	 * Write the An entity primarily responsible for making the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeCreator(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CREATOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Temporal characteristics of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readTemporal(){
		return applyOperator(Operator.READ, null,AURI, TEMPORAL, URI.class, null);
	}


	/**
	 * Write the Temporal characteristics of the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeTemporal(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, TEMPORAL, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Information about who can access the resource or an indication of its security status. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccessRights(){
		return applyOperator(Operator.READ, null,AURI, ACCESS_RIGHTS, URI.class, null);
	}


	/**
	 * Write the Information about who can access the resource or an indication of its security status.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAccessRights(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ACCESS_RIGHTS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date of formal issuance (e.g., publication) of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readIssued(){
		return applyOperator(Operator.READ, null,AURI, ISSUED, Date.class, null);
	}


	/**
	 * Write the Date of formal issuance (e.g., publication) of the resource.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeIssued(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ISSUED, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An account of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readDescription(){
		return applyOperator(Operator.READ, null,AURI, DESCRIPTION, String.class, null);
	}


	/**
	 * Write the An account of the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeDescription(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DESCRIPTION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that supplants, displaces, or supersedes the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReplacedBy(){
		return applyOperator(Operator.READ, null,AURI, IS_REPLACED_BY, String.class, null);
	}


	/**
	 * Write the A related resource that supplants, displaces, or supersedes the described resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeReplacedBy(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_REPLACED_BY, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date (often a range) that the resource became or will become available. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readAvailable(){
		return applyOperator(Operator.READ, null,AURI, AVAILABLE, Date.class, null);
	}


	/**
	 * Write the Date (often a range) that the resource became or will become available.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeAvailable(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, AVAILABLE, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is supplanted, displaced, or superseded by the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReplaces(){
		return applyOperator(Operator.READ, null,AURI, REPLACES, String.class, null);
	}


	/**
	 * Write the A related resource that is supplanted, displaced, or superseded by the described resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeReplaces(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, REPLACES, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A point or period of time associated with an event in the lifecycle of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDate(){
		return applyOperator(Operator.READ, null,AURI, DATE, Date.class, null);
	}


	/**
	 * Write the A point or period of time associated with an event in the lifecycle of the resource.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeDate(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DATE, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A list of subunits of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readTableOfContents(){
		return applyOperator(Operator.READ, null,AURI, TABLE_OF_CONTENTS, String.class, null);
	}


	/**
	 * Write the A list of subunits of the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeTableOfContents(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, TABLE_OF_CONTENTS, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is required by the described resource to support its function, delivery, or coherence. 
	 * 
	 * @return a String
	 */
	public Value<String> readRequires(){
		return applyOperator(Operator.READ, null,AURI, REQUIRES, String.class, null);
	}


	/**
	 * Write the A related resource that is required by the described resource to support its function, delivery, or coherence.
	 * @param value a String
	 */
	public PieceOfKnowledge writeRequires(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, REQUIRES, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The frequency with which items are added to a collection. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccrualPeriodicity(){
		return applyOperator(Operator.READ, null,AURI, ACCRUAL_PERIODICITY, URI.class, null);
	}


	/**
	 * Write the The frequency with which items are added to a collection.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAccrualPeriodicity(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ACCRUAL_PERIODICITY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is substantially the same as the pre-existing described resource, but in another format. 
	 * 
	 * @return a String
	 */
	public Value<String> readFormat(){
		return applyOperator(Operator.READ, null,AURI, HAS_FORMAT, String.class, null);
	}


	/**
	 * Write the A related resource that is substantially the same as the pre-existing described resource, but in another format.
	 * @param value a String
	 */
	public PieceOfKnowledge writeFormat(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_FORMAT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A name given to the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readTitle(){
		return applyOperator(Operator.READ, null,AURI, TITLE, String.class, null);
	}


	/**
	 * Write the A name given to the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeTitle(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, TITLE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date of acceptance of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDateAccepted(){
		return applyOperator(Operator.READ, null,AURI, DATE_ACCEPTED, Date.class, null);
	}


	/**
	 * Write the Date of acceptance of the resource.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeDateAccepted(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DATE_ACCEPTED, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is a version, edition, or adaptation of the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readVersion(){
		return applyOperator(Operator.READ, null,AURI, HAS_VERSION, String.class, null);
	}


	/**
	 * Write the A related resource that is a version, edition, or adaptation of the described resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeVersion(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_VERSION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date on which the resource was changed. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readModified(){
		return applyOperator(Operator.READ, null,AURI, MODIFIED, Date.class, null);
	}


	/**
	 * Write the Date on which the resource was changed.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeModified(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, MODIFIED, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity responsible for making the resource available. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readPublisher(){
		return applyOperator(Operator.READ, null,AURI, PUBLISHER, URI.class, null);
	}


	/**
	 * Write the An entity responsible for making the resource available.
	 * @param value an URI
	 */
	public PieceOfKnowledge writePublisher(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, PUBLISHER, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The topic of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readSubject(){
		return applyOperator(Operator.READ, null,AURI, SUBJECT, String.class, null);
	}


	/**
	 * Write the The topic of the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeSubject(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, SUBJECT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An entity responsible for making contributions to the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readContributor(){
		return applyOperator(Operator.READ, null,AURI, CONTRIBUTOR, URI.class, null);
	}


	/**
	 * Write the An entity responsible for making contributions to the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeContributor(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CONTRIBUTOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The nature or genre of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readType(){
		return applyOperator(Operator.READ, null,AURI, TYPE, URI.class, null);
	}


	/**
	 * Write the The nature or genre of the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeType(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, TYPE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A class of entity, defined in terms of progression through an educational or training context, for which the described resource is intended. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readEducationLevel(){
		return applyOperator(Operator.READ, null,AURI, EDUCATION_LEVEL, URI.class, null);
	}


	/**
	 * Write the A class of entity, defined in terms of progression through an educational or training context, for which the described resource is intended.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeEducationLevel(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, EDUCATION_LEVEL, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Date of copyright. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDateCopyrighted(){
		return applyOperator(Operator.READ, null,AURI, DATE_COPYRIGHTED, Date.class, null);
	}


	/**
	 * Write the Date of copyright.
	 * @param value a Date
	 */
	public PieceOfKnowledge writeDateCopyrighted(Date value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DATE_COPYRIGHTED, Date.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is referenced, cited, or otherwise pointed to by the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReferences(){
		return applyOperator(Operator.READ, null,AURI, REFERENCES, String.class, null);
	}


	/**
	 * Write the A related resource that is referenced, cited, or otherwise pointed to by the described resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeReferences(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, REFERENCES, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readProvenance(){
		return applyOperator(Operator.READ, null,AURI, PROVENANCE, URI.class, null);
	}


	/**
	 * Write the A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeProvenance(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, PROVENANCE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The size or duration of the resource. 
	 * 
	 * @return an String
	 */
	public Value<String> readExtent(){
		return applyOperator(Operator.READ, null,AURI, EXTENT, String.class, null);
	}


	/**
	 * Write the The size or duration of the resource.
	 * @param value an String
	 */
	public PieceOfKnowledge writeExtent(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, EXTENT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the An alternative name for the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readAlternative(){
		return applyOperator(Operator.READ, null,AURI, ALTERNATIVE, String.class, null);
	}


	/**
	 * Write the An alternative name for the resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writeAlternative(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ALTERNATIVE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource in which the described resource is physically or logically included. 
	 * 
	 * @return a String
	 */
	public Value<String> readPartOf(){
		return applyOperator(Operator.READ, null,AURI, IS_PART_OF, String.class, null);
	}


	/**
	 * Write the A related resource in which the described resource is physically or logically included.
	 * @param value a String
	 */
	public PieceOfKnowledge writePartOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_PART_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A related resource that is included either physically or logically in the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readPart(){
		return applyOperator(Operator.READ, null,AURI, HAS_PART, String.class, null);
	}


	/**
	 * Write the A related resource that is included either physically or logically in the described resource.
	 * @param value a String
	 */
	public PieceOfKnowledge writePart(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_PART, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is relevant. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCoverage(){
		return applyOperator(Operator.READ, null,AURI, COVERAGE, URI.class, null);
	}


	/**
	 * Write the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is relevant.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeCoverage(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, COVERAGE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Spatial characteristics of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSpatial(){
		return applyOperator(Operator.READ, null,AURI, SPATIAL, URI.class, null);
	}


	/**
	 * Write the Spatial characteristics of the resource.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeSpatial(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, SPATIAL, URI.class, value).getIsAnnotatedOn();
	}



}

