package org.w3.www.ma_ont;

import java.net.URI;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;

 /**
  * Created by Tobias Buerger, Jean Pierre Evain and Pierre-Antoine Champin with the RDFS Taskforce within the W3C Media Annotation Working Group.
  */
public class MAOntAnnotator extends BaseAnnotator {

	protected static final String APREFIX = "ma-ont";
	protected static final URI AURI = URI.create("http://www.w3.org/ns/ma-ont#");

	public MAOntAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public MAOntAnnotator(Resource resource){
		super(resource);
	}

	protected static final String SAMPLING_RATE = "samplingRate";
	protected static final String HAS_RATING_SYSTEM = "hasRatingSystem";
	protected static final String IDENTIFIER = "identifier";
	protected static final String HAS_CREATOR = "hasCreator";
	protected static final String HAS_FRAGMENT = "hasFragment";
	protected static final String RECORD_DATE = "recordDate";
	protected static final String LOCATION_ALTITUDE = "locationAltitude";
	protected static final String CREATED_IN = "createdIn";
	protected static final String FEATURES = "features";
	protected static final String DEPICTS_FICTIONAL_LOCATION = "depictsFictionalLocation";
	protected static final String NUMBER_OF_TRACKS = "numberOfTracks";
	protected static final String HAS_TRACK = "hasTrack";
	protected static final String HAS_NAMED_FRAGMENT = "hasNamedFragment";
	protected static final String IS_PROVIDED_BY = "isProvidedBy";
	protected static final String FRAME_RATE = "frameRate";
	protected static final String IS_MEMBER_OF = "isMemberOf";
	protected static final String COPYRIGHT = "copyright";
	protected static final String HAS_POLICY = "hasPolicy";
	protected static final String DESCRIPTION = "description";
	protected static final String HAS_LOCATION_COORDINATE_SYSTEM = "hasLocationCoordinateSystem";
	protected static final String DURATION = "duration";
	protected static final String IS_CREATION_LOCATION_OF = "isCreationLocationOf";
	protected static final String HAS_CONTRIBUTOR = "hasContributor";
	protected static final String HAS_CLASSIFICATION = "hasClassification";
	protected static final String IS_CHAPTER_OF = "isChapterOf";
	protected static final String TITLE = "title";
	protected static final String PROVIDES = "provides";
	protected static final String IS_SOURCE_OF = "isSourceOf";
	protected static final String HAS_MEMBER = "hasMember";
	protected static final String HAS_LANGUAGE = "hasLanguage";
	protected static final String HAS_CAPTIONING = "hasCaptioning";
	protected static final String HAS_CREATED = "hasCreated";
	protected static final String HAS_GENRE = "hasGenre";
	protected static final String IS_TARGET_AUDIENCE_OF = "isTargetAudienceOf";
	protected static final String HAS_FORMAT = "hasFormat";
	protected static final String IS_COPYRIGHTED_BY = "isCopyrightedBy";
	protected static final String HAS_PUBLISHED = "hasPublished";
	protected static final String FRAME_HEIGHT = "frameHeight";
	protected static final String HAS_COMPRESSION = "hasCompression";
	protected static final String HAS_SOURCE = "hasSource";
	protected static final String HAS_COPYRIGHT_OVER = "hasCopyrightOver";
	protected static final String LOCATION_LATITUDE = "locationLatitude";
	protected static final String LOCATION_NAME = "locationName";
	protected static final String FRAGMENT_NAME = "fragmentName";
	protected static final String RELEASE_DATE = "releaseDate";
	protected static final String LOCATOR = "locator";
	protected static final String IS_LOCATION_RELATED_TO = "isLocationRelatedTo";
	protected static final String DATE = "date";
	protected static final String IS_NAMED_FRAGMENT_OF = "isNamedFragmentOf";
	protected static final String HAS_SIGNING = "hasSigning";
	protected static final String RATING_VALUE = "ratingValue";
	protected static final String HAS_PUBLISHER = "hasPublisher";
	protected static final String IS_RELATED_TO = "isRelatedTo";
	protected static final String TRACK_NAME = "trackName";
	protected static final String HAS_RELATED_IMAGE = "hasRelatedImage";
	protected static final String FRAME_WIDTH = "frameWidth";
	protected static final String FRAME_SIZE_UNIT = "frameSizeUnit";
	protected static final String HAS_SUBTITLING = "hasSubtitling";
	protected static final String PLAYS_IN = "playsIn";
	protected static final String EDIT_DATE = "editDate";
	protected static final String _IS_RATING_OF = "IsRatingOf";
	protected static final String HAS_RATING = "hasRating";
	protected static final String HAS_CLASSIFICATION_SYSTEM = "hasClassificationSystem";
	protected static final String AVERAGE_BIT_RATE = "averageBitRate";
	protected static final String IS_TRACK_OF = "isTrackOf";
	protected static final String HAS_RELATED_LOCATION = "hasRelatedLocation";
	protected static final String IS_SIGNING_OF = "isSigningOf";
	protected static final String HAS_RELATED_RESOURCE = "hasRelatedResource";
	protected static final String IS_IMAGE_RELATED_TO = "isImageRelatedTo";
	protected static final String MAIN_ORIGINAL_TITLE = "mainOriginalTitle";
	protected static final String IS_FICTIONAL_LOCATION_DEPICTED_IN = "isFictionalLocationDepictedIn";
	protected static final String IS_CAPTIONING_OF = "isCaptioningOf";
	protected static final String HAS_CHAPTER = "hasChapter";
	protected static final String CREATION_DATE = "creationDate";
	protected static final String HAS_ACCESS_CONDITIONS = "hasAccessConditions";
	protected static final String HAS_PERMISSIONS = "hasPermissions";
	protected static final String HAS_KEYWORD = "hasKeyword";
	protected static final String ALTERNATIVE_TITLE = "alternativeTitle";
	protected static final String HAS_TARGET_AUDIENCE = "hasTargetAudience";
	protected static final String LOCATION_LONGITUDE = "locationLongitude";
	protected static final String IS_FRAGMENT_OF = "isFragmentOf";
	protected static final String COLLECTION_NAME = "collectionName";
	protected static final String HAS_AUDIO_DESCRIPTION = "hasAudioDescription";
	protected static final String RATING_SCALE_MIN = "ratingScaleMin";
	protected static final String HAS_CONTRIBUTED_TO = "hasContributedTo";
	protected static final String RATING_SCALE_MAX = "ratingScaleMax";

	/**
	 * Read the Corresponds to 'samplingRate' in the Ontology for Media Resources, in samples per second. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSamplingRate(){
		return applyOperator(Operator.READ, null,AURI, SAMPLING_RATE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'samplingRate' in the Ontology for Media Resources, in samples per second.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeSamplingRate(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, SAMPLING_RATE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'rating.type' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readRatingSystem(){
		return applyOperator(Operator.READ, null,AURI, HAS_RATING_SYSTEM, String.class, null);
	}


	/**
	 * Write the Corresponds to 'rating.type' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeRatingSystem(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_RATING_SYSTEM, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'identifier' in the Ontology for Media Resources. The value being a URI, it is recommended to use owl:sameAs when appropriate, in order to maximize interoperability. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readIdentifier(){
		return applyOperator(Operator.READ, null,AURI, IDENTIFIER, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'identifier' in the Ontology for Media Resources. The value being a URI, it is recommended to use owl:sameAs when appropriate, in order to maximize interoperability.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeIdentifier(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IDENTIFIER, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'creator.creator' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'creator.role'. Note that this property is semantically a subproperty of 'hasContributor'. 
	 * 
	 * @return a String
	 */
	public Value<String> readCreator(){
		return applyOperator(Operator.READ, null,AURI, HAS_CREATOR, String.class, null);
	}


	/**
	 * Write the Corresponds to 'creator.creator' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'creator.role'. Note that this property is semantically a subproperty of 'hasContributor'.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCreator(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CREATOR, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'fragment.role'. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFragment(){
		return applyOperator(Operator.READ, null,AURI, HAS_FRAGMENT, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'fragment.role'.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFragment(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_FRAGMENT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "recordDate". 
	 * 
	 * @return a String
	 */
	public Value<String> readRecordDate(){
		return applyOperator(Operator.READ, null,AURI, RECORD_DATE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "recordDate".
	 * @param value a String
	 */
	public PieceOfKnowledge writeRecordDate(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RECORD_DATE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'location.altitude' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLocationAltitude(){
		return applyOperator(Operator.READ, null,AURI, LOCATION_ALTITUDE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'location.altitude' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLocationAltitude(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LOCATION_ALTITUDE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A subproperty of 'hasRelatedLocation" used to specify where material shooting took place. 
	 * 
	 * @return a String
	 */
	public Value<String> readCreatedIn(){
		return applyOperator(Operator.READ, null,AURI, CREATED_IN, String.class, null);
	}


	/**
	 * Write the A subproperty of 'hasRelatedLocation" used to specify where material shooting took place.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCreatedIn(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CREATED_IN, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'contributor.contributor' in the Ontology for Media Resources with a 'contributor.role' meaning "actor". 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFeatures(){
		return applyOperator(Operator.READ, null,AURI, FEATURES, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'contributor.contributor' in the Ontology for Media Resources with a 'contributor.role' meaning "actor".
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFeatures(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FEATURES, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the A subproperty of 'hasRelatedLocation' used to specify where the action depicted in the media is supposed to take place, as opposed to the location where shooting actually took place (see 'createdIn'). 
	 * 
	 * @return a String
	 */
	public Value<String> readDepictsFictionalLocation(){
		return applyOperator(Operator.READ, null,AURI, DEPICTS_FICTIONAL_LOCATION, String.class, null);
	}


	/**
	 * Write the A subproperty of 'hasRelatedLocation' used to specify where the action depicted in the media is supposed to take place, as opposed to the location where shooting actually took place (see 'createdIn').
	 * @param value a String
	 */
	public PieceOfKnowledge writeDepictsFictionalLocation(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DEPICTS_FICTIONAL_LOCATION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'numTracks.number' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'numTracks.type'. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readNumberOfTracks(){
		return applyOperator(Operator.READ, null,AURI, NUMBER_OF_TRACKS, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'numTracks.number' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'numTracks.type'.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeNumberOfTracks(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, NUMBER_OF_TRACKS, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "track". 
	 * 
	 * @return an URI
	 */
	public Value<URI> readTrack(){
		return applyOperator(Operator.READ, null,AURI, HAS_TRACK, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "track".
	 * @param value an URI
	 */
	public PieceOfKnowledge writeTrack(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_TRACK, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'namedFragment' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readNamedFragment(){
		return applyOperator(Operator.READ, null,AURI, HAS_NAMED_FRAGMENT, String.class, null);
	}


	/**
	 * Write the Corresponds to 'namedFragment' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeNamedFragment(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_NAMED_FRAGMENT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'rating.identifier' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readProvidedBy(){
		return applyOperator(Operator.READ, null,AURI, IS_PROVIDED_BY, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'rating.identifier' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeProvidedBy(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_PROVIDED_BY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'frameRate' in the Ontology for Media Resources, in frame per second. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFrameRate(){
		return applyOperator(Operator.READ, null,AURI, FRAME_RATE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'frameRate' in the Ontology for Media Resources, in frame per second.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFrameRate(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FRAME_RATE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'collection' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readMemberOf(){
		return applyOperator(Operator.READ, null,AURI, IS_MEMBER_OF, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'collection' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeMemberOf(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_MEMBER_OF, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'copyright.copyright' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readCopyright(){
		return applyOperator(Operator.READ, null,AURI, COPYRIGHT, String.class, null);
	}


	/**
	 * Write the Corresponds to 'copyright.copyright' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCopyright(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, COPYRIGHT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'policy' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'policy.type'. 
	 * 
	 * @return a String
	 */
	public Value<String> readPolicy(){
		return applyOperator(Operator.READ, null,AURI, HAS_POLICY, String.class, null);
	}


	/**
	 * Write the Corresponds to 'policy' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'policy.type'.
	 * @param value a String
	 */
	public PieceOfKnowledge writePolicy(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_POLICY, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'description' in the Ontology for Media Resources. This can be specialised by using sub-properties e.g. 'summary' or 'script'. 
	 * 
	 * @return a String
	 */
	public Value<String> readDescription(){
		return applyOperator(Operator.READ, null,AURI, DESCRIPTION, String.class, null);
	}


	/**
	 * Write the Corresponds to 'description' in the Ontology for Media Resources. This can be specialised by using sub-properties e.g. 'summary' or 'script'.
	 * @param value a String
	 */
	public PieceOfKnowledge writeDescription(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DESCRIPTION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'location.coordinateSystem' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readLocationCoordinateSystem(){
		return applyOperator(Operator.READ, null,AURI, HAS_LOCATION_COORDINATE_SYSTEM, String.class, null);
	}


	/**
	 * Write the Corresponds to 'location.coordinateSystem' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeLocationCoordinateSystem(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_LOCATION_COORDINATE_SYSTEM, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'duration' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readDuration(){
		return applyOperator(Operator.READ, null,AURI, DURATION, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'duration' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeDuration(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DURATION, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readCreationLocationOf(){
		return applyOperator(Operator.READ, null,AURI, IS_CREATION_LOCATION_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeCreationLocationOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_CREATION_LOCATION_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'contributor.contributor' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'contributor.role'. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readContributor(){
		return applyOperator(Operator.READ, null,AURI, HAS_CONTRIBUTOR, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'contributor.contributor' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'contributor.role'.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeContributor(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CONTRIBUTOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'targetAudience.classification' in the Ontology for Media Resources. This property is used to provide a value characterising the target audience. 
	 * 
	 * @return a String
	 */
	public Value<String> readClassification(){
		return applyOperator(Operator.READ, null,AURI, HAS_CLASSIFICATION, String.class, null);
	}


	/**
	 * Write the Corresponds to 'targetAudience.classification' in the Ontology for Media Resources. This property is used to provide a value characterising the target audience.
	 * @param value a String
	 */
	public PieceOfKnowledge writeClassification(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CLASSIFICATION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readChapterOf(){
		return applyOperator(Operator.READ, null,AURI, IS_CHAPTER_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeChapterOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_CHAPTER_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'title.title' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'title.type'. 
	 * 
	 * @return a String
	 */
	public Value<String> readTitle(){
		return applyOperator(Operator.READ, null,AURI, TITLE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'title.title' in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'title.type'.
	 * @param value a String
	 */
	public PieceOfKnowledge writeTitle(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, TITLE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readProvides(){
		return applyOperator(Operator.READ, null,AURI, PROVIDES, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeProvides(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, PROVIDES, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readSourceOf(){
		return applyOperator(Operator.READ, null,AURI, IS_SOURCE_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeSourceOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_SOURCE_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readMember(){
		return applyOperator(Operator.READ, null,AURI, HAS_MEMBER, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeMember(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_MEMBER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'language' in the Ontology for Media Resources. The language used in the resource. A controlled vocabulary such as defined in BCP 47 SHOULD be used. This property can also be used to identify the presence of sign language (RFC 5646). By inheritance, the hasLanguage property applies indifferently at the media resource / fragment / track levels. Best practice recommends to use to best possible level of granularity fo describe the usage of language within a media resource including at fragment and track levels. 
	 * 
	 * @return a String
	 */
	public Value<String> readLanguage(){
		return applyOperator(Operator.READ, null,AURI, HAS_LANGUAGE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'language' in the Ontology for Media Resources. The language used in the resource. A controlled vocabulary such as defined in BCP 47 SHOULD be used. This property can also be used to identify the presence of sign language (RFC 5646). By inheritance, the hasLanguage property applies indifferently at the media resource / fragment / track levels. Best practice recommends to use to best possible level of granularity fo describe the usage of language within a media resource including at fragment and track levels.
	 * @param value a String
	 */
	public PieceOfKnowledge writeLanguage(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_LANGUAGE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "captioning". This property can for example point to a spatial fragment, a VideoTrack or a DataTrack. The language of the captioning track can be expressed by attaching a 'hasLanguage' property to the specific track. 
	 * 
	 * @return a String
	 */
	public Value<String> readCaptioning(){
		return applyOperator(Operator.READ, null,AURI, HAS_CAPTIONING, String.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "captioning". This property can for example point to a spatial fragment, a VideoTrack or a DataTrack. The language of the captioning track can be expressed by attaching a 'hasLanguage' property to the specific track.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCaptioning(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CAPTIONING, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readCreated(){
		return applyOperator(Operator.READ, null,AURI, HAS_CREATED, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeCreated(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CREATED, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'genre' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readGenre(){
		return applyOperator(Operator.READ, null,AURI, HAS_GENRE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'genre' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeGenre(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_GENRE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readTargetAudienceOf(){
		return applyOperator(Operator.READ, null,AURI, IS_TARGET_AUDIENCE_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeTargetAudienceOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_TARGET_AUDIENCE_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'format' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readFormat(){
		return applyOperator(Operator.READ, null,AURI, HAS_FORMAT, String.class, null);
	}


	/**
	 * Write the Corresponds to 'format' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeFormat(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_FORMAT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'copyright.identifier' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCopyrightedBy(){
		return applyOperator(Operator.READ, null,AURI, IS_COPYRIGHTED_BY, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'copyright.identifier' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeCopyrightedBy(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_COPYRIGHTED_BY, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readPublished(){
		return applyOperator(Operator.READ, null,AURI, HAS_PUBLISHED, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writePublished(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_PUBLISHED, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'frameSize.height' in the Ontology for Media Resources, measured in frameSizeUnit. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFrameHeight(){
		return applyOperator(Operator.READ, null,AURI, FRAME_HEIGHT, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'frameSize.height' in the Ontology for Media Resources, measured in frameSizeUnit.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFrameHeight(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FRAME_HEIGHT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'compression' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readCompression(){
		return applyOperator(Operator.READ, null,AURI, HAS_COMPRESSION, String.class, null);
	}


	/**
	 * Write the Corresponds to 'compression' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCompression(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_COMPRESSION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'relation' and in the Ontology for Media Resources with a 'relation.type' meaning "source". 
	 * 
	 * @return a String
	 */
	public Value<String> readSource(){
		return applyOperator(Operator.READ, null,AURI, HAS_SOURCE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'relation' and in the Ontology for Media Resources with a 'relation.type' meaning "source".
	 * @param value a String
	 */
	public PieceOfKnowledge writeSource(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_SOURCE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readCopyrightOver(){
		return applyOperator(Operator.READ, null,AURI, HAS_COPYRIGHT_OVER, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeCopyrightOver(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_COPYRIGHT_OVER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'location.latitude' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLocationLatitude(){
		return applyOperator(Operator.READ, null,AURI, LOCATION_LATITUDE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'location.latitude' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLocationLatitude(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LOCATION_LATITUDE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'location.name' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readLocationName(){
		return applyOperator(Operator.READ, null,AURI, LOCATION_NAME, String.class, null);
	}


	/**
	 * Write the Corresponds to 'location.name' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeLocationName(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LOCATION_NAME, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'namedFragment.label' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readFragmentName(){
		return applyOperator(Operator.READ, null,AURI, FRAGMENT_NAME, String.class, null);
	}


	/**
	 * Write the Corresponds to 'namedFragment.label' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeFragmentName(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FRAGMENT_NAME, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "releaseDate". 
	 * 
	 * @return a String
	 */
	public Value<String> readReleaseDate(){
		return applyOperator(Operator.READ, null,AURI, RELEASE_DATE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "releaseDate".
	 * @param value a String
	 */
	public PieceOfKnowledge writeReleaseDate(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RELEASE_DATE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'locator' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLocator(){
		return applyOperator(Operator.READ, null,AURI, LOCATOR, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'locator' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLocator(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LOCATOR, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readLocationRelatedTo(){
		return applyOperator(Operator.READ, null,AURI, IS_LOCATION_RELATED_TO, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeLocationRelatedTo(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_LOCATION_RELATED_TO, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to date.date in the ontology for Media Resources. Subproperties can be used to distinguish different values of 'date.type'. The recommended range is 'xsd:dateTime' (for compliance with OWL2-QL and OWL2-RL) but other time-related datatypes may be used (e.g. 'xsd:gYear', 'xsd:date'...). 
	 * 
	 * @return a String
	 */
	public Value<String> readDate(){
		return applyOperator(Operator.READ, null,AURI, DATE, String.class, null);
	}


	/**
	 * Write the Corresponds to date.date in the ontology for Media Resources. Subproperties can be used to distinguish different values of 'date.type'. The recommended range is 'xsd:dateTime' (for compliance with OWL2-QL and OWL2-RL) but other time-related datatypes may be used (e.g. 'xsd:gYear', 'xsd:date'...).
	 * @param value a String
	 */
	public PieceOfKnowledge writeDate(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, DATE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readNamedFragmentOf(){
		return applyOperator(Operator.READ, null,AURI, IS_NAMED_FRAGMENT_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeNamedFragmentOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_NAMED_FRAGMENT_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "signing". This property can for example point to a spatial fragment or a VideoTrack. The sign language of the captioning track can be expressed by attaching a 'hasLanguage' property to the specific track. 
	 * 
	 * @return a String
	 */
	public Value<String> readSigning(){
		return applyOperator(Operator.READ, null,AURI, HAS_SIGNING, String.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "signing". This property can for example point to a spatial fragment or a VideoTrack. The sign language of the captioning track can be expressed by attaching a 'hasLanguage' property to the specific track.
	 * @param value a String
	 */
	public PieceOfKnowledge writeSigning(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_SIGNING, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'rating.value' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRatingValue(){
		return applyOperator(Operator.READ, null,AURI, RATING_VALUE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'rating.value' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRatingValue(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RATING_VALUE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'publisher' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readPublisher(){
		return applyOperator(Operator.READ, null,AURI, HAS_PUBLISHER, String.class, null);
	}


	/**
	 * Write the Corresponds to 'publisher' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writePublisher(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_PUBLISHER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readRelatedTo(){
		return applyOperator(Operator.READ, null,AURI, IS_RELATED_TO, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeRelatedTo(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_RELATED_TO, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment.name' in the Ontology for Media Resources, for Track fragments. 
	 * 
	 * @return a String
	 */
	public Value<String> readTrackName(){
		return applyOperator(Operator.READ, null,AURI, TRACK_NAME, String.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment.name' in the Ontology for Media Resources, for Track fragments.
	 * @param value a String
	 */
	public PieceOfKnowledge writeTrackName(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, TRACK_NAME, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'relation' and in the Ontology for Media Resources with a 'relation.type' meaning "related image". 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRelatedImage(){
		return applyOperator(Operator.READ, null,AURI, HAS_RELATED_IMAGE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'relation' and in the Ontology for Media Resources with a 'relation.type' meaning "related image".
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRelatedImage(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_RELATED_IMAGE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'frameSize.width' in the Ontology for Media Resources measured in frameSizeUnit. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFrameWidth(){
		return applyOperator(Operator.READ, null,AURI, FRAME_WIDTH, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'frameSize.width' in the Ontology for Media Resources measured in frameSizeUnit.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeFrameWidth(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FRAME_WIDTH, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'frameSize.unit' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readFrameSizeUnit(){
		return applyOperator(Operator.READ, null,AURI, FRAME_SIZE_UNIT, String.class, null);
	}


	/**
	 * Write the Corresponds to 'frameSize.unit' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeFrameSizeUnit(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, FRAME_SIZE_UNIT, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "subtitling". 
	 * 
	 * @return a String
	 */
	public Value<String> readSubtitling(){
		return applyOperator(Operator.READ, null,AURI, HAS_SUBTITLING, String.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "subtitling".
	 * @param value a String
	 */
	public PieceOfKnowledge writeSubtitling(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_SUBTITLING, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readPlaysIn(){
		return applyOperator(Operator.READ, null,AURI, PLAYS_IN, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writePlaysIn(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, PLAYS_IN, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "editDate". 
	 * 
	 * @return a String
	 */
	public Value<String> readEditDate(){
		return applyOperator(Operator.READ, null,AURI, EDIT_DATE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "editDate".
	 * @param value a String
	 */
	public PieceOfKnowledge writeEditDate(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, EDIT_DATE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readIsRatingOf(){
		return applyOperator(Operator.READ, null,AURI, _IS_RATING_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeIsRatingOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, _IS_RATING_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'rating' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRating(){
		return applyOperator(Operator.READ, null,AURI, HAS_RATING, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'rating' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRating(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_RATING, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'targetAudience.identifier' in the Ontology for Media Resources. This is used to identify the reference sheme against which the target audience has been characterised. 
	 * 
	 * @return a String
	 */
	public Value<String> readClassificationSystem(){
		return applyOperator(Operator.READ, null,AURI, HAS_CLASSIFICATION_SYSTEM, String.class, null);
	}


	/**
	 * Write the Corresponds to 'targetAudience.identifier' in the Ontology for Media Resources. This is used to identify the reference sheme against which the target audience has been characterised.
	 * @param value a String
	 */
	public PieceOfKnowledge writeClassificationSystem(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CLASSIFICATION_SYSTEM, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'averageBitRate' in the Ontology for Media Resources, expressed in kilobits/second. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAverageBitRate(){
		return applyOperator(Operator.READ, null,AURI, AVERAGE_BIT_RATE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'averageBitRate' in the Ontology for Media Resources, expressed in kilobits/second.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeAverageBitRate(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, AVERAGE_BIT_RATE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readTrackOf(){
		return applyOperator(Operator.READ, null,AURI, IS_TRACK_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeTrackOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_TRACK_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'location' in the Ontology for Media Resources. Subproperties are provided to specify, when possible, the relation between the media resource and the location. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRelatedLocation(){
		return applyOperator(Operator.READ, null,AURI, HAS_RELATED_LOCATION, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'location' in the Ontology for Media Resources. Subproperties are provided to specify, when possible, the relation between the media resource and the location.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRelatedLocation(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_RELATED_LOCATION, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readSigningOf(){
		return applyOperator(Operator.READ, null,AURI, IS_SIGNING_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeSigningOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_SIGNING_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'relation' and in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'relation.type'. 
	 * 
	 * @return a String
	 */
	public Value<String> readRelatedResource(){
		return applyOperator(Operator.READ, null,AURI, HAS_RELATED_RESOURCE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'relation' and in the Ontology for Media Resources. Subproperties can be used to distinguish different values of 'relation.type'.
	 * @param value a String
	 */
	public PieceOfKnowledge writeRelatedResource(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_RELATED_RESOURCE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readImageRelatedTo(){
		return applyOperator(Operator.READ, null,AURI, IS_IMAGE_RELATED_TO, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeImageRelatedTo(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_IMAGE_RELATED_TO, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'title.title' in the Ontology for Media Resources with a 'title.type' meaning "original". 
	 * 
	 * @return a String
	 */
	public Value<String> readMainOriginalTitle(){
		return applyOperator(Operator.READ, null,AURI, MAIN_ORIGINAL_TITLE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'title.title' in the Ontology for Media Resources with a 'title.type' meaning "original".
	 * @param value a String
	 */
	public PieceOfKnowledge writeMainOriginalTitle(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, MAIN_ORIGINAL_TITLE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readFictionalLocationDepictedIn(){
		return applyOperator(Operator.READ, null,AURI, IS_FICTIONAL_LOCATION_DEPICTED_IN, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeFictionalLocationDepictedIn(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_FICTIONAL_LOCATION_DEPICTED_IN, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readCaptioningOf(){
		return applyOperator(Operator.READ, null,AURI, IS_CAPTIONING_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeCaptioningOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_CAPTIONING_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "actor". 
	 * 
	 * @return a String
	 */
	public Value<String> readChapter(){
		return applyOperator(Operator.READ, null,AURI, HAS_CHAPTER, String.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "actor".
	 * @param value a String
	 */
	public PieceOfKnowledge writeChapter(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CHAPTER, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "creationDate". 
	 * 
	 * @return a String
	 */
	public Value<String> readCreationDate(){
		return applyOperator(Operator.READ, null,AURI, CREATION_DATE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'date.date' in the Ontology for Media Resources with a 'date.type' meaning "creationDate".
	 * @param value a String
	 */
	public PieceOfKnowledge writeCreationDate(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, CREATION_DATE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'policy' in the Ontology for Media Resources with a 'policy.type' "access conditions". 
	 * 
	 * @return a String
	 */
	public Value<String> readAccessConditions(){
		return applyOperator(Operator.READ, null,AURI, HAS_ACCESS_CONDITIONS, String.class, null);
	}


	/**
	 * Write the Corresponds to 'policy' in the Ontology for Media Resources with a 'policy.type' "access conditions".
	 * @param value a String
	 */
	public PieceOfKnowledge writeAccessConditions(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_ACCESS_CONDITIONS, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'policy' in the Ontology for Media Resources with a 'policy.type' meaning "permissions". 
	 * 
	 * @return a String
	 */
	public Value<String> readPermissions(){
		return applyOperator(Operator.READ, null,AURI, HAS_PERMISSIONS, String.class, null);
	}


	/**
	 * Write the Corresponds to 'policy' in the Ontology for Media Resources with a 'policy.type' meaning "permissions".
	 * @param value a String
	 */
	public PieceOfKnowledge writePermissions(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_PERMISSIONS, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'keyword' in the Ontology for Media Resources. 
	 * 
	 * @return a String
	 */
	public Value<String> readKeyword(){
		return applyOperator(Operator.READ, null,AURI, HAS_KEYWORD, String.class, null);
	}


	/**
	 * Write the Corresponds to 'keyword' in the Ontology for Media Resources.
	 * @param value a String
	 */
	public PieceOfKnowledge writeKeyword(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_KEYWORD, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'title.title' in the Ontology for Media Resources with a 'title.type' meaning "alternative". 
	 * 
	 * @return a String
	 */
	public Value<String> readAlternativeTitle(){
		return applyOperator(Operator.READ, null,AURI, ALTERNATIVE_TITLE, String.class, null);
	}


	/**
	 * Write the Corresponds to 'title.title' in the Ontology for Media Resources with a 'title.type' meaning "alternative".
	 * @param value a String
	 */
	public PieceOfKnowledge writeAlternativeTitle(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, ALTERNATIVE_TITLE, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'targetAudience' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readTargetAudience(){
		return applyOperator(Operator.READ, null,AURI, HAS_TARGET_AUDIENCE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'targetAudience' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeTargetAudience(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_TARGET_AUDIENCE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'location.longitude' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLocationLongitude(){
		return applyOperator(Operator.READ, null,AURI, LOCATION_LONGITUDE, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'location.longitude' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeLocationLongitude(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, LOCATION_LONGITUDE, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readFragmentOf(){
		return applyOperator(Operator.READ, null,AURI, IS_FRAGMENT_OF, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeFragmentOf(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, IS_FRAGMENT_OF, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the The name by which a collection (e.g. series) is known. 
	 * 
	 * @return a String
	 */
	public Value<String> readCollectionName(){
		return applyOperator(Operator.READ, null,AURI, COLLECTION_NAME, String.class, null);
	}


	/**
	 * Write the The name by which a collection (e.g. series) is known.
	 * @param value a String
	 */
	public PieceOfKnowledge writeCollectionName(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, COLLECTION_NAME, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "audio-description". 
	 * 
	 * @return a String
	 */
	public Value<String> readAudioDescription(){
		return applyOperator(Operator.READ, null,AURI, HAS_AUDIO_DESCRIPTION, String.class, null);
	}


	/**
	 * Write the Corresponds to 'fragment' in the Ontology for Media Resources with a 'fragment.role' meaning "audio-description".
	 * @param value a String
	 */
	public PieceOfKnowledge writeAudioDescription(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_AUDIO_DESCRIPTION, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'rating.min' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRatingScaleMin(){
		return applyOperator(Operator.READ, null,AURI, RATING_SCALE_MIN, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'rating.min' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRatingScaleMin(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RATING_SCALE_MIN, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the null 
	 * 
	 * @return a String
	 */
	public Value<String> readContributedTo(){
		return applyOperator(Operator.READ, null,AURI, HAS_CONTRIBUTED_TO, String.class, null);
	}


	/**
	 * Write the null
	 * @param value a String
	 */
	public PieceOfKnowledge writeContributedTo(String value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, HAS_CONTRIBUTED_TO, String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Corresponds to 'rating.max' in the Ontology for Media Resources. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRatingScaleMax(){
		return applyOperator(Operator.READ, null,AURI, RATING_SCALE_MAX, URI.class, null);
	}


	/**
	 * Write the Corresponds to 'rating.max' in the Ontology for Media Resources.
	 * @param value an URI
	 */
	public PieceOfKnowledge writeRatingScaleMax(URI value){
		return applyOperator(Operator.WRITE, APREFIX,AURI, RATING_SCALE_MAX, URI.class, value).getIsAnnotatedOn();
	}



}

